==> dojo_1.15.0+dfsg1.orig.tar.xz: dojo-release-1.15.0-src/dojo/cldr/nls/zh-tw/gregorian.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "本週六",
	"field-sat-relative+1": "下週六",
	"field-sun-relative+-1": "上週日",
	"field-mon-relative+-1": "上週一",
	"field-minute": "分鐘",
	"eraNames": [
		"西元前",
		"西元"
	],
	"dateTimeFormat-full": "{1}{0}",
	"field-weekday": "週天",
	"dateFormatItem-yQQQ": "y年QQQ",
	"field-era": "年代",
	"dateFormatItem-Gy": "G y 年",
	"field-hour": "小時",
	"quarters-standAlone-abbr": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"timeFormat-full": "ah:mm:ss [zzzz]",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"dateFormatItem-yMM": "y-MM",
	"field-sun-relative+0": "本週日",
	"field-sun-relative+1": "下週日",
	"field-wed-relative+-1": "上週三",
	"dateFormatItem-Ed": "d日（E）",
	"eraAbbr": [
		"西元前",
		"西元"
	],
	"field-day-relative+2": "後天",
	"dateFormatItem-GyMMMd": "G y 年 M 月 d 日",
	"field-zone": "時區",
	"field-tue-relative+0": "本週二",
	"dateFormatItem-Ehm": "E a h:mm",
	"field-tue-relative+1": "下週二",
	"field-week-relative+-1": "上週",
	"field-sat-relative+-1": "上週六",
	"$locale": "zh-hant-tw",
	"quarters-standAlone-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"field-fri-relative+0": "本週五",
	"field-fri-relative+1": "下週五",
	"months-standAlone-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-week": "週",
	"field-week-relative+0": "本週",
	"dateFormatItem-Ehms": "E a h:mm:ss",
	"field-week-relative+1": "下週",
	"timeFormat-long": "ah:mm:ss [z]",
	"dateFormatItem-yQQQQ": "y年QQQQ",
	"field-month-relative+1": "下個月",
	"dateFormatItem-H": "H時",
	"field-fri-relative+-1": "上週五",
	"quarters-format-abbr": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"field-second": "秒",
	"dateFormatItem-GyMMMEd": "Gy年M月d日 E",
	"field-tue-relative+-1": "上週二",
	"dateFormatItem-GyMMM": "G y 年 M 月",
	"dateFormatItem-MEd": "M/d（E）",
	"field-mon-relative+0": "本週一",
	"field-mon-relative+1": "下週一",
	"field-second-relative+0": "現在",
	"field-thu-relative+0": "本週四",
	"dateFormat-short": "y/M/d",
	"field-thu-relative+1": "下週四",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-EHm": "E HH:mm",
	"dateFormatItem-yMEd": "y/M/d（E）",
	"field-wed-relative+0": "本週三",
	"months-format-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-wed-relative+1": "下週三",
	"field-month-relative+-1": "上個月",
	"quarters-format-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"eraNarrow": [
		"西元前",
		"西元"
	],
	"dateFormatItem-h": "ah時",
	"field-thu-relative+-1": "上週四"
}
//end v1.x content
);

==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/zh-tw/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E ah:mm",
	"field-second-relative+0": "現在",
	"field-quarter-relative+-1": "上一季",
	"field-weekday": "週天",
	"$locale": "zh-hant-tw",
	"dateFormatItem-yQQQ": "y年QQQ",
	"dateFormatItem-yMEd": "y/M/d（E）",
	"field-wed-relative+0": "本週三",
	"dateFormatItem-hmsv": "ah:mm:ss [v]",
	"field-wed-relative+1": "下週三",
	"dateFormatItem-GyMMMEd": "Gy年M月d日 E",
	"dateFormatItem-MMMEd": "M月d日 E",
	"eraNarrow": [
		"西元前",
		"西元"
	],
	"dateFormatItem-yMM": "y/MM",
	"field-tue-relative+-1": "上週二",
	"field-hour-relative+0": "這一小時",
	"field-fri-relative+-1": "上週五",
	"field-wed-relative+-1": "上週三",
	"months-format-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"dateFormat-full": "y年M月d日 EEEE",
	"field-thu-relative+-1": "上週四",
	"field-era": "年代",
	"dateFormatItem-yM": "y/M",
	"months-standAlone-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"quarters-format-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"dateFormatItem-yQQQQ": "y年QQQQ",
	"timeFormat-long": "ah:mm:ss [z]",
	"field-hour": "小時",
	"field-sat-relative+0": "本週六",
	"field-sat-relative+1": "下週六",
	"timeFormat-full": "ah:mm:ss [zzzz]",
	"dateFormatItem-MMMMW": "MMM的第W週",
	"field-thu-relative+0": "本週四",
	"field-thu-relative+1": "下週四",
	"field-day-relative+2": "後天",
	"dateFormatItem-H": "H時",
	"quarters-format-abbr": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"quarters-standAlone-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"field-sun-relative+0": "本週日",
	"field-sun-relative+1": "下週日",
	"quarters-standAlone-abbr": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"dateFormatItem-yw": "y年的第w週",
	"eraAbbr": [
		"西元前",
		"西元"
	],
	"field-minute": "分鐘",
	"dateFormatItem-h": "ah時",
	"field-minute-relative+0": "這一分鐘",
	"field-quarter-relative+0": "這一季",
	"field-quarter-relative+1": "下一季",
	"dateFormatItem-MEd": "M/d（E）",
	"field-fri-relative+0": "本週五",
	"field-fri-relative+1": "下週五",
	"field-zone": "時區",
	"field-month-relative+-1": "上個月",
	"eraNames": [
		"西元前",
		"西元"
	],
	"field-quarter": "季",
	"field-tue-relative+0": "本週二",
	"field-tue-relative+1": "下週二",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "本週一",
	"field-mon-relative+1": "下週一",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E ah:mm:ss",
	"field-sat-relative+-1": "上週六",
	"dateFormatItem-yMMMEd": "y年M月d日 E",
	"field-sun-relative+-1": "上週日",
	"field-month-relative+1": "下個月",
	"dateFormatItem-Ed": "d E",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "週",
	"dateFormatItem-Hmsv": "HH:mm:ss [v]",
	"field-week-relative+-1": "上週",
	"dateFormatItem-Hmv": "HH:mm [v]",
	"dateFormatItem-hmv": "ah:mm [v]",
	"field-mon-relative+-1": "上週一",
	"field-week-relative+0": "本週",
	"field-week-relative+1": "下週"
}
//end v1.x content
);
